@@ -828,6 +828,9 @@ bool cs_dump_page(struct linux_binprm *bprm, unsigned long pos,
 		  struct cs_page_dump *dump)
 {
 	struct page *page;
+#if defined(CONFIG_MMU) && LINUX_VERSION_CODE >= KERNEL_VERSION(5, 15, 0)
+	int ret;
+#endif
 	/* dump->data is released by cs_start_execve(). */
 	if (!dump->data) {
 		dump->data = kzalloc(PAGE_SIZE, GFP_NOFS);
@@ -836,7 +839,13 @@ bool cs_dump_page(struct linux_binprm *bprm, unsigned long pos,
 	}
 	/* Same with get_arg_page(bprm, pos, 0) in fs/exec.c */
 #ifdef CONFIG_MMU
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 9, 0)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 15, 0)
+	mmap_read_lock(bprm->mm);
+	ret = get_user_pages_remote(bprm->mm, pos, 1, FOLL_FORCE, &page, NULL, NULL);
+	mmap_read_unlock(bprm->mm);
+	if (ret <= 0)
+		return false;
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(5, 9, 0)
 	if (get_user_pages_remote(bprm->mm, pos, 1, FOLL_FORCE, &page,
 				  NULL, NULL) <= 0)
 		return false;
